NGX - Heros Devices 0.8.0 documentation

Skip to content
Back to top
View this page

# NGX

From: Rohde Schwarz

Class: `herosdevices.hardware.rohde_schwarz.ngx.NGX`

Driver Quality Index: beta

A channel of a RS NGX PSU with TCP/IP connection.

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.rohde_schwarz.ngx.NGX` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
resource | <class ‘str’> |  |
channels | tuple[tuple[int, str], …] | ((1, ‘ch1’),) |
keep_alive | <class ‘bool’> | True |

The following JSON strings can be used to start a HERO device representation of `NGX` using BOSS.

    {
        "_id": "ngp8004",
        "classname": "herosdevices.hardware.rohde_schwarz.NGX",
        "arguments": {
            "resource": "TCPIP::my_device_address::INSTR",
            "channels": [
                [
                    1,
                    "ch1"
                ],
                [
                    2,
                    "ch2"
                ],
                [
                    3,
                    "ch3"
                ],
                [
                    4,
                    "ch4"
                ]
            ]
        },
        "datasource": {
            "async": false,
            "interval": 15
        }
    }

from examples/rohde_schwarz/ngp8004.json

    {
        "_id": "my_NGX",
        "classname": "herosdevices.hardware.rohde_schwarz.ngx.NGX",
        "arguments": {
            "resource": "<class 'str'>",
            "channels": [
                [
                    1,
                    "ch1"
                ]
            ],
            "keep_alive": true
        }
    }

generated from signature